@@ -35,14 +35,10 @@ class DenonAVRDirac(DenonAVRFoundation):
 
     def setup(self) -> None:
         """Ensure that the instance is initialized."""
-        self._device.telnet_api.register_callback(
-            "PS", self._async_dirac_filter_callback
-        )
+        self._device.telnet_api.register_callback("PS", self._dirac_filter_callback)
         self._is_setup = True
 
-    async def _async_dirac_filter_callback(
-        self, zone: str, event: str, parameter: str
-    ) -> None:
+    def _dirac_filter_callback(self, zone: str, event: str, parameter: str) -> None:
         """Handle Dirac filter change event."""
         if event == "PS" and parameter[0:5] == "DIRAC":
             self._dirac_filter = DIRAC_FILTER_MAP_LABELS[parameter[6:]]
