@@ -150,7 +150,7 @@ class TestMainFunctions:
 
         return resp
 
-    async def _callback(self, zone, event, parameter):
+    def _callback(self, zone, event, parameter):
         self.future.set_result(True)
 
     @pytest.mark.asyncio
